@@ -55,6 +55,8 @@
         }
     }
   }
+
+  $checkup = PFCMD('checkup');
 ?>
 
 <div id=status> 
@@ -69,6 +71,24 @@
         <? print_status_table() ?>
     </td>
   </tr>
+  <tr class=header>
+    <td class=header colspan=2 align=center>Configuration check-up</td>
+  </tr>
+  <tr class=content>
+    <td class=checkup colspan=2 align=center>
+    <?php
+      if($checkup) {
+        ?><textarea rows=10 cols=100 disabled name=checkup><?php
+        foreach($checkup as $line) {
+          print "$line\n";
+        }
+        ?></textarea><?php
+      } else {
+        ?><p align=center>Configuration checkup failed.</p><?php
+      }
+    ?>
+    </td>
+  </tr>
 </table>
 </div>
 
