@@ -1,6 +1,6 @@
 <?php
 /**
- * TODO short desc
+ * common.php: The Web Admin interface's main library
  *
  * TODO long desc
  * 
@@ -20,7 +20,8 @@
  * USA.
  * 
  * @author      Olivier Bilodeau <obilodeau@inverse.ca>
- * @copyright   2008-2010 Inverse inc.
+ * @author      Francois Gaudreault <fgaudreault@inverse.ca>
+ * @copyright   2008-2011 Inverse inc.
  * @license     http://opensource.org/licenses/gpl-2.0.php      GPL
  */
 
@@ -338,7 +339,7 @@ if($sajax){
       }
 
       if($this->editable) {
-        print "    <td>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td>\n"; 
+        print "    <td class='action'>&nbsp;</td>\n"; 
       }
       if($this->scannable) {
         print "    <td&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;></td>\n"; 
@@ -539,9 +540,10 @@ if($sajax){
                  print "  </form>";
                }
              } elseif (($current_top == 'configuration') && ($current_sub=='violation')) {
-               print "  <a href=\"javascript:popUp('/$current_top/" . $current_sub . "_edit.php?item=" . $this->rows[$i]['vid'] . "',500,400)\" title='Edit this record'><img src='/images/famfamfam_silk_icons/page_edit.png' alt=\"[ Edit ]\"></a>\n";
-               print "  <a href=\"javascript:popUp('/$current_top/" . $current_sub . "_add.php?item=" . $this->rows[$i]['vid'] . "',500,400)\" title='Clone this record'><img src='/images/famfamfam_silk_icons/page_add.png' alt=\"[ Add ]\"></a>\n";
-               if (($this->rows[$i]['vid'] != '1100001') && ($this->rows[$i]['vid'] != 1100004) && ($this->rows[$i]['vid'] != 1100005) && ($this->rows[$i]['vid'] != 1100009) && ($this->rows[$i]['vid'] != 1100010) && ($this->rows[$i]['vid'] != 1200001) && ($this->rows[$i]['vid'] != 1200003) && ($this->rows[$i]['vid'] != 'defaults')) {
+               print "  <a href=\"". $this->rows[$i]['url'] . "\" title='Preview remediation page' target='_blank'><img src='/images/famfamfam_silk_icons/page_world.png' alt=\"[ Preview ]\"></a>\n";
+               print "  <a href=\"javascript:popUp('/$current_top/" . $current_sub . "_edit.php?item=" . $this->rows[$i]['vid'] . "',600,500)\" title='Edit this record'><img src='/images/famfamfam_silk_icons/page_edit.png' alt=\"[ Edit ]\"></a>\n";
+               print "  <a href=\"javascript:popUp('/$current_top/" . $current_sub . "_add.php?item=" . $this->rows[$i]['vid'] . "',600,500)\" title='Clone this record'><img src='/images/famfamfam_silk_icons/page_add.png' alt=\"[ Add ]\"></a>\n";
+               if (!is_protected_vid($this->rows[$i]['vid'])) {
                  print "<form action='/$current_top/$current_sub.php?filter=$filter&amp;sort=$sort&amp;direction=$direction&amp;page_num=$this->page_num&amp;per_page=$this->per_page' method='post'>";
                  print "  <input type='hidden' name='action' value='delete'>\n";
                  print "  <input type='hidden' name='commit' value='true'>\n";
@@ -1119,7 +1121,7 @@ function PrintSubNav($menu){
     }
     $new = array();
     foreach($new_unknowns as $new_unknown){
-      $new[$new_unknown['dhcp_fingerprint']] = $new_unknown['vendor'];
+      $new[$new_unknown['dhcp_fingerprint']] = $new_unknown['vendor'] . ":" . $new_unknown['computername'] . ":" . $new_unknown['user_agent'];
     }
 
     # These next few lines kept track of what fingerprints have been submitted.
@@ -1133,14 +1135,14 @@ function PrintSubNav($menu){
     if(count($diff)>0){
      $_SESSION['ui_global_prefs']['shared_fingerprints']=array_merge($current, $diff);
       save_global_prefs_to_file();
-      foreach($diff as $fprint => $vendor){
-        $content.= "$fprint:$vendor\n";
+      foreach($diff as $fprint => $details){
+        $content.= "$fprint:$details\n";
       }
 
-      print "<form name='share_fingerprints' method='POST' action='http://www.packetfence.org/fingerprints.php?ref=$abs_url/$current_top/$current_sub.php'>";
-      print "  <input type='hidden' name='fingerprints' value='$content'>";
-      print "</form>";
-      print "<script>document.share_fingerprints.submit()</script>";
+      $msg .= "<form name='share_fingerprints' method='POST' action='http://www.packetfence.org/fingerprintsv2.php?ref=$abs_url/$current_top/$current_sub.php'>";
+      $msg .= "  <input type='hidden' name='fingerprints' value='$content'>";
+      $msg .= "</form>";
+      $msg .= "<script>document.share_fingerprints.submit()</script>";
     }
     else{
       $msg .= "No new unknown fingerprints to share.";
@@ -1148,6 +1150,53 @@ function PrintSubNav($menu){
     return $msg;
   }
 
+  function share_useragents($new_unknowns){
+    global $logger;
+    global $abs_url, $current_top, $current_sub;
+
+    if(!$new_unknowns){
+      $my_table = new table("report unknownuseragents");
+      $new_unknowns = set_default($my_table->rows, array());
+    }
+    if (! is_array($new_unknowns)) {
+      $new_unknowns = array();
+    }
+    $new = array();
+    foreach($new_unknowns as $new_unknown){
+      $new[$new_unknown['user_agent']] = array(
+          'browser' => $new_unknown['browser'],
+          'os' => $new_unknown['os'],
+          'computername' => $new_unknown['computername'],
+          'dhcp_fingerprint' => $new_unknown['dhcp_fingerprint'],
+          'description' => $new_unknown['description']
+      );
+    }
+
+    # These next few lines kept track of what fingerprints have been submitted.
+    if (isset($_SESSION['ui_global_prefs']['shared_useragent_fingerprints'])) {
+      $current = $_SESSION['ui_global_prefs']['shared_useragent_fingerprints'];
+    } else {
+      $current = array();
+    }
+    $diff = array_diff_assoc($new, $current);
+
+    if(count($diff)>0){
+      $_SESSION['ui_global_prefs']['shared_useragent_fingerprints']=array_merge($current, $diff);
+      save_global_prefs_to_file();
+      $content = base64_encode(gzcompress(serialize($diff)));
+      $logger->debug("ready to send the following: $content");
+
+      $msg .= "<form name='share_useragent_fingerprints' method='POST' action='http://www.packetfence.org/useragents.php?ref=$abs_url/$current_top/$current_sub.php'>";
+      $msg .= "  <input type='hidden' name='useragent_fingerprints' value='$content'>";
+      $msg .= "</form>";
+      $msg .= "<script>document.share_useragent_fingerprints.submit()</script>";
+    }
+    else{
+      $msg .= "No new unknown User-Agent fingerprints to share.";
+    }
+    return $msg;
+  }
+
   function printSelect($values, $type, $default = false , $extra = false){
     if(!is_array($values)){
       print "<select $extra>\n";
