@@ -19,8 +19,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
  * USA.
  * 
+ * @author      Olivier Bilodeau <obilodeau@inverse.ca>
+ * @author      Francois Gaudreault <fgaudreault@inverse.ca>
  * @author      Dominik Gehl <dgehl@inverse.ca>
- * @copyright   2008-2010 Inverse inc.
+ * @copyright   2008-2011 Inverse inc.
  * @license     http://opensource.org/licenses/gpl-2.0.php      GPL
  */
 
@@ -31,7 +33,14 @@
 
   include_once('../header.php');
 
-  $active_available = array('registered', 'unregistered', 'os', 'osclass', 'unknownprints', 'openviolations', 'statics');
+  $active_available = array(
+    'registered', 'unregistered', 
+    'os', 'osclass', 
+    'unknownprints', 'unknownuseragents', 
+    'openviolations', 'statics',
+    'connectiontype', 'connectiontypereg',
+    'ssid'
+  );
   $type = set_default($_REQUEST['type'], 'ipmachistory');
   $subtype = set_default($_GET['subtype'], '');
 
@@ -344,6 +353,18 @@ array('owner', 'person/lookup.php')));
       $msg .= share_fingerprints($my_table->rows);
     }
 
+    if($msg){
+      $extra_goodness .= "<div id='message_box'>$msg</div>";
+    }
+  } elseif (strstr($type,'unknownuseragents')){
+    get_global_conf();
+
+    ## Sharing Fingerprints ##
+    if($_REQUEST['upload']){
+      if($msg){ $msg.="<br>"; }
+      $msg .= share_useragents($my_table->rows);
+    }
+
     if($msg){
       $extra_goodness .= "<div id='message_box'>$msg</div>";
     }
