@@ -51,7 +51,7 @@ sub supportsFloatingDevice {
 
 =item supportsWiredMacAuth 
 
-Returns 1 if switch type supports MAC Authentication (Wired Access Authorization through RADIUS)
+Returns 1 if switch type supports Wired MAC Authentication (Wired Access Authorization through RADIUS)
 
 =cut
 sub supportsWiredMacAuth {
@@ -79,6 +79,36 @@ sub supportsWiredDot1x {
     return $FALSE;
 }
 
+=item supportsWirelessMacAuth 
+
+Returns 1 if switch type supports Wireless MAC Authentication (RADIUS Authentication)
+
+=cut
+sub supportsWirelessMacAuth {
+    my ( $this ) = @_;
+    my $logger = Log::Log4perl::get_logger( ref($this) );
+
+    $logger->error(
+        "Wireless MAC Authentication is not supported on switch type " . ref($this) . ". "
+        . "Please let us know what hardware you are using."
+    );
+    return $FALSE;
+}
+
+=item supportsWirelessDot1x - Returns 1 if switch type supports Wireless 802.1X (aka WPA-Enterprise)
+
+=cut
+sub supportsWirelessDot1x {
+    my ( $this ) = @_;
+    my $logger = Log::Log4perl::get_logger( ref($this) );
+
+    $logger->error(
+        "Wireless 802.1X (WPA-Enterprise) is not supported on switch type " . ref($this) . ". "
+        . "Please let us know what hardware you are using."
+    );
+    return $FALSE;
+}
+
 =item supportsRadiusVoip
 
 =cut
@@ -106,10 +136,6 @@ sub new {
         '_customVlan3'              => undef,
         '_customVlan4'              => undef,
         '_customVlan5'              => undef,
-        '_dbHostname'               => undef,
-        '_dbName'                   => undef,
-        '_dbPassword'               => undef,
-        '_dbUser'                   => undef,
         '_error'                    => undef,
         '_guestVlan'                => undef,
         '_ip'                       => undef,
@@ -118,7 +144,6 @@ sub new {
         '_macSearchesMaxNb'         => undef,
         '_macSearchesSleepInterval' => undef,
         '_mode'                     => undef,
-        '_mysqlConnection'          => undef,
         '_normalVlan'               => undef,
         '_registrationVlan'         => undef,
         '_sessionRead'              => undef,
@@ -177,14 +202,6 @@ sub new {
                     $this->{_customVlan4} = $argv{$_};
         } elsif (/^-?customVlan5$/i) {
                     $this->{_customVlan5} = $argv{$_};
-        } elsif (/^-?dbHostname$/i) {
-            $this->{_dbHostname} = $argv{$_};
-        } elsif (/^-?dbName$/i) {
-            $this->{_dbName} = $argv{$_};
-        } elsif (/^-?dbPassword$/i) {
-            $this->{_dbPassword} = $argv{$_};
-        } elsif (/^-?dbUser$/i) {
-            $this->{_dbUser} = $argv{$_};
         } elsif (/^-?guestVlan$/i) {
             $this->{_guestVlan} = $argv{$_};
         } elsif (/^-?ip$/i) {
@@ -452,41 +469,6 @@ sub disconnectWrite {
     return 1;
 }
 
-=item connectMySQL - create MySQL database connection
-
-=cut
-# FIXME a connect but no disconnect? is this here useful at all?
-sub connectMySQL {
-    my $this   = shift;
-    my $logger = Log::Log4perl::get_logger( ref($this) );
-
-    $logger->debug("initializing database connection");
-    if ( defined( $this->{_mysqlConnection} ) ) {
-        $logger->debug("database connection already exists - reusing it");
-        return 1;
-    }
-    $logger->debug( "connecting to database server "
-            . $this->{_dbHostname}
-            . " as user "
-            . $this->{_dbUser}
-            . "; database name is "
-            . $this->{_dbName} );
-    $this->{_mysqlConnection}
-        = DBI->connect( "dbi:mysql:dbname="
-            . $this->{_dbName}
-            . ";host="
-            . $this->{_dbHostname},
-        $this->{_dbUser}, $this->{_dbPassword}, { PrintError => 0 } );
-    if ( !defined( $this->{_mysqlConnection} ) ) {
-        $logger->error(
-            "couldn't connection to MySQL server: " . DBI->errstr );
-        return 0;
-    }
-    locationlog_db_prepare( $this->{_mysqlConnection} );
-    node_db_prepare( $this->{_mysqlConnection} );
-    return 1;
-}
-
 =item setVlan
 
 Set a port to a VLAN validating some rules first then calling the switch's _setVlan.
@@ -954,7 +936,7 @@ sub isProductionMode {
     return ( $this->getMode() eq 'production' );
 }
 
-=item isDiscoveryMode - return True if $switch-E<gt>{_mode} eq 'discory'
+=item isDiscoveryMode - return True if $switch-E<gt>{_mode} eq 'discovery'
 
 =cut
 
@@ -1050,20 +1032,20 @@ sub getMacAtIfIndex {
     my $start  = time;
     my @macArray;
 
-    # we try to get the MAC 30 times or for 2 minutes whichever comes first
+    # we try to get the MAC macSearchesMaxNb times or for 2 minutes whichever comes first
     do {
-        sleep(2) unless ( $i == 0 );
-        $logger->debug( "attempt "
-                . ( $i + 1 )
-                . " to obtain mac at "
-                . $this->{_ip}
-                . " ifIndex $ifIndex" );
+        sleep($this->{_macSearchesSleepInterval}) unless ( $i == 0 );
+        $logger->debug( "attempt " . ( $i + 1 ) . " to obtain mac at " . $this->{_ip} . " ifIndex $ifIndex" );
         @macArray = $this->_getMacAtIfIndex($ifIndex);
         $i++;
-    } while (($i < 30) && ((time-$start) < 120) && (scalar(@macArray) == 0));
+    } while (
+        ($i < $this->{_macSearchesMaxNb}) # number of attempts smaller than this parameter
+        && ((time-$start) < 120) # total time spent smaller than 120 seconds (TODO extract into parameter)
+        && (scalar(@macArray) == 0) # still not found
+    );
 
     if (scalar(@macArray) == 0) {
-        if ($i >= 30) {
+        if ($i >= $this->{_macSearchesMaxNb}) {
             $logger->warn("Tried to grab MAC address at ifIndex $ifIndex "
                 ."on switch ".$this->{_ip}." 30 times and failed");
         } else {
@@ -1424,6 +1406,64 @@ sub _authorizeMAC {
     return 1;
 }
 
+=item authorizeCurrentMacWithNewVlan
+
+Authorize MAC already in secure table on the new VLAN (and deauth from old VLAN).
+This is meant to be called in _setVlan on switches which have a VLAN aware port-security table.
+This is because _setVlan changes the underlying VLAN but doesn't authorize the MAC on the new VLAN.
+
+This method was in the Foundry module first then duplicated in SMC.
+When the third implementation came that needed this feature I decided to extract it and have it sit here since
+it's quite generic.
+
+=cut
+sub authorizeCurrentMacWithNewVlan {
+    my ($this, $ifIndex, $newVlan, $oldVlan) = @_;
+
+    return $this->_authorizeCurrentMacWithNewVlan($ifIndex, $newVlan, $oldVlan);
+}
+
+
+=item _authorizeCurrentMacWithNewVlan
+
+Actual implementation of authorizeCurrentMacWithNewVlan
+
+=cut
+sub _authorizeCurrentMacWithNewVlan {
+    my ($this, $ifIndex, $newVlan, $oldVlan) = @_;
+
+    my $secureTableHashRef = $this->getSecureMacAddresses($ifIndex);
+
+    # hash is valid and has one MAC
+    my $valid = (ref($secureTableHashRef) eq 'HASH');
+    my $mac_count = scalar(keys %{$secureTableHashRef});
+    if ($valid && $mac_count == 1) {
+
+        # normal case
+        # grab MAC
+        my $mac = (keys %{$secureTableHashRef})[0];
+        $this->authorizeMAC($ifIndex, $mac, $mac, $oldVlan, $newVlan);
+        return 1;
+    } elsif ($valid && $mac_count > 1) {
+
+        # VoIP case
+        # check every MAC
+        foreach my $mac (keys %{$secureTableHashRef}) {
+
+            # for every MAC check every VLAN
+            foreach my $vlan (@{$secureTableHashRef->{$mac}}) {
+                # is VLAN equals to old VLAN
+                if ($vlan == $oldVlan) {
+                    # then we need to remove that MAC from that VLAN
+                    $this->authorizeMAC($ifIndex, $mac, $mac, $oldVlan, $newVlan);
+                }
+            }
+        }
+        return 1;
+    }
+    return;
+}
+
 =item getRegExpFromList - analyze a list and determine a regexp pattern from this list (used for show mac-address-table)
 
 =cut
@@ -2254,66 +2294,22 @@ sub NasPortToIfIndex {
 
 Called when a ReAssignVlan trap is received for a switch-port in Wired MAC Authentication.
 
-Default behavior is to bounce the port if there's no IPT device on it.
-If there is and we should have isolated the device send an email to the admins.
+Default behavior is to bounce the port 
 
 =cut
 sub handleReAssignVlanTrapForWiredMacAuth {
     my ($this, $ifIndex) = @_;
     my $logger = Log::Log4perl::get_logger(ref($this));
 
-    my $switch_ip = $this->{'_ip'};
-    my @locationlog = locationlog_view_open_switchport_no_VoIP( $switch_ip, $ifIndex );
-    if (!(@locationlog) || !defined($locationlog[0]->{'mac'}) || ($locationlog[0]->{'mac'} eq '' )) {
-        $logger->warn( "received reAssignVlan trap on $switch_ip ifIndex $ifIndex but can't determine non VoIP MAC");
-        return;
-    }
-
-    my $mac = $locationlog[0]->{'mac'};
-    my $hasPhone = $this->hasPhoneAtIfIndex($ifIndex);
-
     # TODO extract that behavior in a method call in pf::vlan so it can be overridden easily
-    if ( !$hasPhone ) {
-        $logger->info( "no VoIP phone is currently connected at " . $switch_ip
-            . " ifIndex $ifIndex. Flipping port admin status"
-        );
-        $this->bouncePort($ifIndex);
 
-    } else {
+    $logger->warn("Until CoA is implemented we will bounce the port on VLAN re-assignment traps for MAC-Auth");
 
-        $logger->info(
-            "A VoIP phone is currently connected at $switch_ip ifIndex $ifIndex. Leaving everything as it is."
-        ); 
-        # TODO perform CoA (when implemented)
-
-        require pf::violation;
-        my @violations = pf::violation::violation_view_open_desc($mac);
-        if ( scalar(@violations) > 0 ) {
-            my %message;
-            $message{'subject'} = "VLAN isolation of $mac behind VoIP phone";
-            $message{'message'} = "The following computer has been isolated behind a VoIP phone\n";
-            $message{'message'} .= "MAC: $mac\n";
-
-            my $node_info = node_view($mac);
-            $message{'message'} .= "Owner: " . $node_info->{'pid'} . "\n";
-            $message{'message'} .= "Computer Name: " . $node_info->{'computername'} . "\n";
-            $message{'message'} .= "Notes: " . $node_info->{'notes'} . "\n";
-            $message{'message'} .= "Switch: " . $switch_ip . "\n";
-            $message{'message'} .= "Port (ifIndex): " . $ifIndex . "\n\n";
-            $message{'message'} .= "The violation details are\n";
-
-            foreach my $violation (@violations) {
-                $message{'message'} .= "Description: "
-                    . $violation->{'description'} . "\n";
-                $message{'message'} .= "Start: "
-                    . $violation->{'start_date'} . "\n";
-            }
-            $logger->info(
-                "sending email to admin regarding isolation of $mac behind VoIP phone"
-            );
-            pfmailer(%message);
-        }
-    }
+    # TODO perform CoA instead (when implemented)
+    # actually once CoA will be implemented, we should consider offering the same option to users
+    # as we currently do with port-security and VoIP which is bounce or not bounce and suffer consequences
+    # this should be a choice exposed in configuration and not hidden in code
+    $this->bouncePort($ifIndex);
 }
 
 
