@@ -28,12 +28,14 @@ use strict;
 use warnings;
 use diagnostics;
 
-use base ('pf::SNMP::Cisco');
-use Log::Log4perl;
 use Carp;
+use Log::Log4perl;
 use Net::Appliance::Session;
 use Net::SNMP;
-use Data::Dumper;
+
+use base ('pf::SNMP::Cisco');
+
+use pf::config;
 
 =head1 SUBROUTINES
 
@@ -41,6 +43,13 @@ TODO: This list is incomplete
 
 =over
 
+=cut
+
+# CAPABILITIES
+# access technology supported
+sub supportsWirelessDot1x { return $TRUE; }
+sub supportsWirelessMacAuth { return $TRUE; }
+
 =item deauthenticateMac
 
 Warning: this method should _never_ be called in a thread. Net::Appliance::Session is not thread 
