@@ -2,17 +2,16 @@ package pf::SNMP::Cisco::Catalyst_3750;
 
 =head1 NAME
 
-pf::SNMP::Cisco::Catalyst_3750 - Object oriented module to access SNMP enabled Cisco Catalyst 3750 switches
+pf::SNMP::Cisco::Catalyst_3750 - Object oriented module to access and configure Cisco Catalyst 3750 switches
 
-=head1 SYNOPSIS
+=head1 STATUS
 
-The pf::SNMP::Cisco::Catalyst_3750 module implements an object oriented interface
-to access SNMP enabled Cisco::Catalyst_3750 switches.
-
-This modules extends pf::SNMP::Cisco::Catalyst_2950.
+This module is currently only a placeholder, see pf::SNMP::Cisco::Catalyst_2950.
 
 The minimum required firmware version is 12.2(25)SEE2.
 
+802.1X support was never tested by Inverse.
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
 F<conf/switches.conf>
@@ -33,7 +32,7 @@ Regis Balzard <rbalzard@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006-2010 Inverse inc.
+Copyright (C) 2006-2011 Inverse inc.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
