@@ -7,11 +7,7 @@ manage Extreme Networks' Summit switches
 
 =head1 STATUS
 
-This module is currently only a placeholder, all the logic resides in Extreme.pm
-
-Currently only supports linkUp / linkDown mode
-
-Developed and tested on Summit X250e-48p running on image version 12.0.0.4
+This module is currently only a placeholder, see pf::SNMP::Extreme.
 
 =cut
 
@@ -22,13 +18,17 @@ use Log::Log4perl;
 use Net::SNMP;
 use base ('pf::SNMP::Extreme');
 
+# importing switch constants
+use pf::SNMP::constants;
+use pf::util;
+
 =head1 AUTHOR
 
 Olivier Bilodeau <obilodeau@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009 Inverse inc.
+Copyright (C) 2009,2010 Inverse inc.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
