@@ -29,10 +29,15 @@ use strict;
 use warnings;
 use diagnostics;
 
-use base ('pf::SNMP');
 use Log::Log4perl;
 use Net::SNMP;
 
+use pf::config;
+use pf::util;
+
+use base ('pf::SNMP');
+
+use pf::config;
 =head1 METHODS
 
 TODO: This list is incomplete
@@ -44,15 +49,15 @@ sub getVersion {
     my ($this)        = @_;
     my $oid_s5ChasVer = '1.3.6.1.4.1.45.1.6.3.1.5.0';
     my $logger        = Log::Log4perl::get_logger( ref($this) );
+
     if ( !$this->connectRead() ) {
         return '';
     }
+
     $logger->trace("SNMP get_request for s5ChasVer: $oid_s5ChasVer");
-    my $result = $this->{_sessionRead}
-        ->get_request( -varbindlist => [$oid_s5ChasVer] );
-    if ( exists( $result->{$oid_s5ChasVer} )
-        && ( $result->{$oid_s5ChasVer} ne 'noSuchInstance' ) )
-    {
+
+    my $result = $this->{_sessionRead}->get_request( -varbindlist => [$oid_s5ChasVer] );
+    if ( exists( $result->{$oid_s5ChasVer} ) && ( $result->{$oid_s5ChasVer} ne 'noSuchInstance' ) ) {
         return $result->{$oid_s5ChasVer};
     }
     return '';
@@ -221,9 +226,8 @@ sub getVlan {
 
 sub _setVlan {
     my ( $this, $ifIndex, $newVlan, $oldVlan, $switch_locker_ref ) = @_;
-    my $OID_rcVlanPortMembers = '1.3.6.1.4.1.2272.1.3.2.1.11';    #RC-VLAN-MIB
-    my $OID_rcVlanPortDefaultVlanId
-        = '1.3.6.1.4.1.2272.1.3.3.1.7';                           #RC-VLAN-MIB
+    my $OID_rcVlanPortMembers = '1.3.6.1.4.1.2272.1.3.2.1.11'; #RC-VLAN-MIB
+    my $OID_rcVlanPortDefaultVlanId = '1.3.6.1.4.1.2272.1.3.3.1.7'; #RC-VLAN-MIB
     my $logger = Log::Log4perl::get_logger( ref($this) );
     my $result;
 
@@ -234,53 +238,42 @@ sub _setVlan {
         return 0;
     }
 
-    $logger->trace( "locking - trying to lock \$switch_locker{"
-            . $this->{_ip}
-            . "} in _setVlan" );
+    $logger->trace( "locking - trying to lock \$switch_locker{" . $this->{_ip} . "} in _setVlan" );
+
     {
         lock %{ $switch_locker_ref->{ $this->{_ip} } };
-        $logger->trace( "locking - \$switch_locker{"
-                . $this->{_ip}
-                . "} locked in _setVlan" );
-        $this->{_sessionRead}->translate(0);
+        $logger->trace( "locking - \$switch_locker{" . $this->{_ip} . "} locked in _setVlan" );
+
         $logger->trace("SNMP get_request for rcVlanPortMembers");
+        $this->{_sessionRead}->translate(0);
         $result = $this->{_sessionRead}->get_request(
             -varbindlist => [
                 "$OID_rcVlanPortMembers.$oldVlan",
                 "$OID_rcVlanPortMembers.$newVlan"
             ]
         );
-        my $oldPortMembers
-            = $this->modifyBitmask(
-            $result->{"$OID_rcVlanPortMembers.$oldVlan"},
-            $ifIndex, 0 );
-        my $newPortMembers
-            = $this->modifyBitmask(
-            $result->{"$OID_rcVlanPortMembers.$newVlan"},
-            $ifIndex, 1 );
         $this->{_sessionRead}->translate(1);
+        my $oldPortMembers = $this->modifyBitmask( $result->{"$OID_rcVlanPortMembers.$oldVlan"}, $ifIndex, 0 );
+        my $newPortMembers = $this->modifyBitmask( $result->{"$OID_rcVlanPortMembers.$newVlan"}, $ifIndex, 1 );
 
-        $logger->trace(
-            "SNMP set_request for OID_rcVlanPortMembers: $OID_rcVlanPortMembers"
-        );
+
+        $logger->trace( "SNMP set_request for OID_rcVlanPortMembers: $OID_rcVlanPortMembers");
         $result = $this->{_sessionWrite}->set_request(
             -varbindlist => [
-                "$OID_rcVlanPortMembers.$newVlan",
-                Net::SNMP::OCTET_STRING,
-                $newPortMembers,
-                "$OID_rcVlanPortMembers.$oldVlan",
-                Net::SNMP::OCTET_STRING,
-                $oldPortMembers,
-                "$OID_rcVlanPortDefaultVlanId.$ifIndex",
-                Net::SNMP::INTEGER,
-                $newVlan
+                "$OID_rcVlanPortMembers.$newVlan", Net::SNMP::OCTET_STRING, $newPortMembers,
+                "$OID_rcVlanPortMembers.$oldVlan", Net::SNMP::OCTET_STRING, $oldPortMembers,
+                "$OID_rcVlanPortDefaultVlanId.$ifIndex", Net::SNMP::INTEGER, $newVlan
             ]
         );
     }
-    $logger->trace( "locking - \$switch_locker{"
-            . $this->{_ip}
-            . "} unlocked in _setVlan" );
-    return ( defined($result) );
+    $logger->trace( "locking - \$switch_locker{" . $this->{_ip} . "} unlocked in _setVlan" );
+
+    # if $result is defined, it works we can return $TRUE
+    return $TRUE if (defined($result));
+
+    # otherwise report failure
+    $logger->warn("setting VLAN failed with " . $this->{_sessionWrite}->error());
+    return;
 }
 
 
@@ -298,10 +291,10 @@ sub getBoardIndexWidth {
 
 =item getFirstBoardIndex
 
-First board id varies from one BayStack to another. 
-It doesn't vary by model, it seems that it is based on whether the switch has been stacked on not (in its lifetime).
+First board id varies from one BayStack to another based on what seems to be cosmic rays. 
+This method is useful to work-around that problem.
 
-Returns either 0 or 1
+Should return either 0 or 1
 
 =cut
 sub getFirstBoardIndex {
@@ -316,7 +309,7 @@ sub getFirstBoardIndex {
     my $result = $this->{_sessionRead}->get_next_request(-varbindlist => [$OID_s5SbsAuthCfgBrdIndx]);
 
     foreach my $key ( sort keys %{$result} ) {
-        if($result->{$key} =~ /^$OID_s5SbsAuthCfgBrdIndx\.(\d+)/){
+        if($key =~ /^$OID_s5SbsAuthCfgBrdIndx\.(\d+)/){
             return $1;
         }
     }
@@ -333,8 +326,6 @@ sub getBoardPortFromIfIndex {
     return ( $board, $port );
 }
 
-
-
 sub getIfIndexFromBoardPort {
     my ( $this, $board, $port ) = @_;
     return ( ( $board - $this->getFirstBoardIndex() ) * $this->getBoardIndexWidth() + $port );
@@ -343,30 +334,26 @@ sub getIfIndexFromBoardPort {
 sub getAllSecureMacAddresses {
     my ($this) = @_;
     my $logger = Log::Log4perl::get_logger( ref($this) );
-    my $OID_s5SbsAuthCfgAccessCtrlType
-        = '1.3.6.1.4.1.45.1.6.5.3.10.1.4';    #S5-SWITCH-BAYSECURE-MIB
+    my $OID_s5SbsAuthCfgAccessCtrlType = '1.3.6.1.4.1.45.1.6.5.3.10.1.4'; #S5-SWITCH-BAYSECURE-MIB
 
     my $secureMacAddrHashRef = {};
     if ( !$this->connectRead() ) {
         return $secureMacAddrHashRef;
     }
-    my $result = $this->{_sessionRead}
-        ->get_table( -baseoid => "$OID_s5SbsAuthCfgAccessCtrlType" );
+
+    my $result = $this->{_sessionRead}->get_table( -baseoid => "$OID_s5SbsAuthCfgAccessCtrlType" );
     while ( my ( $oid_including_mac, $ctrlType ) = each( %{$result} ) ) {
-        if ((   $oid_including_mac
-                =~ /^$OID_s5SbsAuthCfgAccessCtrlType\.([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)$/
-            )
-            && ( $ctrlType == 1 )
-            )
-        {
-            my $boardIndx = $1;
-            my $portIndx  = $2;
-            my $ifIndex
-                = $this->getIfIndexFromBoardPort( $boardIndx, $portIndx );
-            my $oldMac = sprintf( "%02x:%02x:%02x:%02x:%02x:%02x",
-                $3, $4, $5, $6, $7, $8 );
-            push @{ $secureMacAddrHashRef->{$oldMac}->{$ifIndex} },
-                $this->getVlan($ifIndex);
+        if (( $oid_including_mac =~ 
+            /^$OID_s5SbsAuthCfgAccessCtrlType
+                \.([0-9]+)\.([0-9]+)                                 # boardIndex, portIndex
+                \.([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)   # MAC address
+            $/x) && ( $ctrlType == 1 )) {
+
+                my $boardIndx = $1;
+                my $portIndx  = $2;
+                my $ifIndex = $this->getIfIndexFromBoardPort( $boardIndx, $portIndx );
+                my $oldMac = oid2mac($3);
+                push @{ $secureMacAddrHashRef->{$oldMac}->{$ifIndex} }, $this->getVlan($ifIndex);
         }
     }
 
@@ -376,8 +363,7 @@ sub getAllSecureMacAddresses {
 sub getSecureMacAddresses {
     my ( $this, $ifIndex ) = @_;
     my $logger = Log::Log4perl::get_logger( ref($this) );
-    my $OID_s5SbsAuthCfgAccessCtrlType
-        = '1.3.6.1.4.1.45.1.6.5.3.10.1.4';    #S5-SWITCH-BAYSECURE-MIB
+    my $OID_s5SbsAuthCfgAccessCtrlType = '1.3.6.1.4.1.45.1.6.5.3.10.1.4'; #S5-SWITCH-BAYSECURE-MIB
     my $secureMacAddrHashRef = {};
 
     if ( !$this->connectRead() ) {
@@ -389,18 +375,18 @@ sub getSecureMacAddresses {
     $logger->trace(
         "SNMP get_table for s5SbsAuthCfgAccessCtrlType: $OID_s5SbsAuthCfgAccessCtrlType.$boardIndx.$portIndx"
     );
-    my $result = $this->{_sessionRead}->get_table(
-        -baseoid => "$OID_s5SbsAuthCfgAccessCtrlType.$boardIndx.$portIndx" );
+
+    my $result = $this->{_sessionRead}->get_table( -baseoid => "$OID_s5SbsAuthCfgAccessCtrlType.$boardIndx.$portIndx" );
+
     while ( my ( $oid_including_mac, $ctrlType ) = each( %{$result} ) ) {
-        if ((   $oid_including_mac
-                =~ /^$OID_s5SbsAuthCfgAccessCtrlType\.$boardIndx\.$portIndx\.([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)$/
-            )
-            && ( $ctrlType == 1 )
-            )
-        {
-            my $oldMac = sprintf( "%02x:%02x:%02x:%02x:%02x:%02x",
-                $1, $2, $3, $4, $5, $6 );
-            push @{ $secureMacAddrHashRef->{$oldMac} }, $oldVlan;
+        if (( $oid_including_mac =~ 
+            /^$OID_s5SbsAuthCfgAccessCtrlType
+                \.$boardIndx\.$portIndx                             # boardIndex, portIndex
+                \.([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)  # MAC address
+            $/x ) && ( $ctrlType == 1 )) {
+
+                my $oldMac = oid2mac($1);
+                push @{ $secureMacAddrHashRef->{$oldMac} }, $oldVlan;
         }
     }
 
@@ -431,65 +417,42 @@ sub authorizeMAC {
 #called with $authorized set to true, creates a new line to authorize the MAC
 #when $authorized is set to false, deletes an existing line
 sub _authorizeMAC {
-    my ( $this, $ifIndex, $MACHexString, $authorize ) = @_;
+    my ( $this, $ifIndex, $mac, $authorize ) = @_;
     my $OID_s5SbsAuthCfgAccessCtrlType = '1.3.6.1.4.1.45.1.6.5.3.10.1.4';
     my $OID_s5SbsAuthCfgStatus         = '1.3.6.1.4.1.45.1.6.5.3.10.1.5';
     my $logger = Log::Log4perl::get_logger( ref($this) );
 
     if ( !$this->isProductionMode() ) {
-        $logger->info(
-            "not in production mode ... we won't delete an entry from the SecureMacAddrTable"
-        );
+        $logger->info( "not in production mode ... we won't delete an entry from the SecureMacAddrTable" );
         return 1;
     }
 
-    my ( $boardIndx, $portIndx ) = $this->getBoardPortFromIfIndex($ifIndex);
-
-    my $cfgStatus = ($authorize) ? 2 : 3;
-
-    #convert MAC into decimal
-    #TODO extract this logic into a MAC2OID sub in util
-    my @MACArray = split( /:/, $MACHexString );
-    my $MACDecString = '';
-    foreach my $hexPiece (@MACArray) {
-        if ( $MACDecString ne '' ) {
-            $MACDecString .= ".";
-        }
-        $MACDecString .= hex($hexPiece);
-    }
-
     if ( !$this->connectWrite() ) {
         return 0;
     }
-    my $result;
 
+    # setup config parameters
+    my ( $boardIndx, $portIndx ) = $this->getBoardPortFromIfIndex($ifIndex);
+    my $cfgStatus = ($authorize) ? 2 : 3;
+    my $mac_oid = mac2oid($mac);
+
+    my $result;
     if ($authorize) {
-        $logger->trace(
-            "SNMP set_request for s5SbsAuthCfgAccessCtrlType: $OID_s5SbsAuthCfgAccessCtrlType"
-        );
+        $logger->trace( "SNMP set_request for s5SbsAuthCfgAccessCtrlType: $OID_s5SbsAuthCfgAccessCtrlType" );
         $result = $this->{_sessionWrite}->set_request(
             -varbindlist => [
-                "$OID_s5SbsAuthCfgAccessCtrlType.$boardIndx.$portIndx.$MACDecString",
-                Net::SNMP::INTEGER,
-                1,
-                "$OID_s5SbsAuthCfgStatus.$boardIndx.$portIndx.$MACDecString",
-                Net::SNMP::INTEGER,
-                $cfgStatus
+                "$OID_s5SbsAuthCfgAccessCtrlType.$boardIndx.$portIndx.$mac_oid", Net::SNMP::INTEGER, $TRUE,
+                "$OID_s5SbsAuthCfgStatus.$boardIndx.$portIndx.$mac_oid", Net::SNMP::INTEGER, $cfgStatus
             ]
         );
     } else {
-        $logger->trace(
-            "SNMP set_request for s5SbsAuthCfgStatus: $OID_s5SbsAuthCfgStatus"
-        );
+        $logger->trace( "SNMP set_request for s5SbsAuthCfgStatus: $OID_s5SbsAuthCfgStatus" );
         $result = $this->{_sessionWrite}->set_request(
             -varbindlist => [
-                "$OID_s5SbsAuthCfgStatus.$boardIndx.$portIndx.$MACDecString",
-                Net::SNMP::INTEGER,
-                $cfgStatus
+                "$OID_s5SbsAuthCfgStatus.$boardIndx.$portIndx.$mac_oid", Net::SNMP::INTEGER, $cfgStatus
             ]
         );
     }
-
     return ( defined($result) );
 }
 
@@ -519,7 +482,11 @@ sub isPortSecurityEnabled {
     my $oid_s5SbsSecurityAction         = '1.3.6.1.4.1.45.1.6.5.3.5';
     my $oid_s5SbsCurrentPortSecurStatus = '1.3.6.1.4.1.45.1.6.5.3.11.1.6';
 
-    my ( $boardIndx, $portIndx ) = $this->getBoardPortFromIfIndex($ifIndex);
+    # careful readers will notice that we don't use getBoardPortFromIfIndex here. 
+    # That's because Nortel thought that it made sense to start BoardIndexes differently for different OIDs
+    # on the same switch!!! 
+    my $boardIndx = (1 + int( $ifIndex / $this->getBoardIndexWidth() ));
+    my $portIndx = ( $ifIndex % $this->getBoardIndexWidth() );
 
     my $s5SbsSecurityStatus         = undef;
     my $s5SbsSecurityAction         = undef;
@@ -530,7 +497,8 @@ sub isPortSecurityEnabled {
     }
 
     $logger->trace(
-        "SNMP get_next_request for s5SbsSecurityStatus: $oid_s5SbsSecurityStatus and s5SbsSecurityAction: $oid_s5SbsSecurityAction"
+        "SNMP get_next_request for s5SbsSecurityStatus: $oid_s5SbsSecurityStatus and " .
+        "s5SbsSecurityAction: $oid_s5SbsSecurityAction"
     );
     my $result = $this->{_sessionRead}->get_next_request( -varbindlist =>
             [ "$oid_s5SbsSecurityStatus", "$oid_s5SbsSecurityAction" ] );
@@ -564,13 +532,16 @@ sub isPortSecurityEnabled {
         }
     }
 
+    # error conditions
+    return $FALSE if (!defined($s5SbsSecurityStatus) || $s5SbsSecurityStatus eq 'noSuchInstance');
+    return $FALSE if (!defined($s5SbsSecurityAction) || $s5SbsSecurityAction eq 'noSuchInstance');
+
     return (
-               defined($s5SbsSecurityStatus)
-            && $s5SbsSecurityStatus == 1
-            && defined($s5SbsSecurityAction)
+            $s5SbsSecurityStatus == 1
             && ( $s5SbsSecurityAction == 6 || $s5SbsSecurityAction == 2 )
-            && ( ( !defined($s5SbsCurrentPortSecurStatus) )
-            || ( $s5SbsCurrentPortSecurStatus >= 2 ) )
+            && (!defined($s5SbsCurrentPortSecurStatus) 
+                || $s5SbsCurrentPortSecurStatus eq 'noSuchInstance' 
+                || $s5SbsCurrentPortSecurStatus >= 2)
     );
 }
 
