@@ -251,6 +251,50 @@ Readonly::Scalar our $DISASSOCIATE => 1;
 
 =back
 
+=head1 THREECOM
+
+3Com constants
+
+=over
+
+=cut
+package THREECOM;
+
+=item hwdot1qTpFdbSetStatus
+
+ other(1),
+ learned(3),
+ static(6),
+ dynamic(7),
+ blackhole(9),
+ security(11)
+
+=cut
+Readonly::Scalar our $OTHER => 1;
+Readonly::Scalar our $LEARNED => 3;
+Readonly::Scalar our $STATIC => 6;
+
+
+=item hwdot1qTpFdbSetOperate
+
+ add(1),
+ delete(2)
+
+=cut
+Readonly::Scalar our $ADD => 1;
+Readonly::Scalar our $DELETE => 2;
+
+
+=item NAS-Port constants
+
+Used for NAS-Port to ifIndex translation
+
+=cut
+Readonly::Scalar our $NAS_PORT_OFFSET => 16781312;
+Readonly::Scalar our $NAS_PORTS_PER_PORT_RANGE => 4096;
+
+=back
+
 =head1 AUTHOR
 
 Olivier Bilodeau <obilodeau@inverse.ca>
@@ -259,7 +303,7 @@ Regis Balzard <rbalzard@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2010 Inverse inc.
+Copyright (C) 2010-2011 Inverse inc.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
