@@ -21,13 +21,14 @@ F<pf.conf.defaults>, F<networks.conf>, F<dhcp_fingerprints.conf>, F<oui.txt>, F<
 use strict;
 use warnings;
 use Config::IniFiles;
-use File::Spec;
-use Net::Netmask;
 use Date::Parse;
-use Log::Log4perl;
 use File::Basename qw(basename);
-use threads;
+use File::Spec;
+use Log::Log4perl;
+use Net::Netmask;
+use POSIX;
 use Readonly;
+use threads;
 
 # Categorized by feature, pay attention when modifying
 our (
@@ -42,7 +43,7 @@ our (
     $oui_file, $oui_url,
     $floating_devices_file, %ConfigFloatingDevices,
     %connection_type, %connection_type_to_str, %connection_type_explained,
-    $blackholemac, $portscan_sid, @valid_trigger_types, $thread, $default_pid, $fqdn,
+    $blackholemac, $portscan_sid, $thread, $default_pid, $fqdn,
     %CAPTIVE_PORTAL
 );
 
@@ -62,7 +63,7 @@ BEGIN {
         $dhcp_fingerprints_file $dhcp_fingerprints_url 
         $oui_file $oui_url
         $floating_devices_file %ConfigFloatingDevices
-        $blackholemac $portscan_sid @valid_trigger_types $thread $default_pid $fqdn
+        $blackholemac $portscan_sid @VALID_TRIGGER_TYPES $thread $default_pid $fqdn
         $FALSE $TRUE
         WIRELESS_802_1X WIRELESS_MAC_AUTH WIRED_802_1X WIRED_MAC_AUTH WIRED_SNMP_TRAPS WIRELESS WIRED EAP UNKNOWN
         VOIP NO_VOIP
@@ -70,6 +71,8 @@ BEGIN {
         %connection_type %connection_type_to_str %connection_type_explained
         $RADIUS_API_LEVEL $VLAN_API_LEVEL
         %CAPTIVE_PORTAL
+        normalize_time
+        $LOG4PERL_RELOAD_TIMER
     );
 }
 
@@ -104,7 +107,7 @@ $floating_devices_file  = $conf_dir . "/floating_network_device.conf";
 $oui_url               = 'http://standards.ieee.org/regauth/oui/oui.txt';
 $dhcp_fingerprints_url = 'http://www.packetfence.org/dhcp_fingerprints.conf';
 
-@valid_trigger_types = ( "scan", "detect", "internal", "os", "vendormac", "useragent" );
+Readonly our @VALID_TRIGGER_TYPES => ( "scan", "detect", "internal", "os", "vendormac", "useragent" );
 
 $portscan_sid = 1200003;
 $default_pid  = 1;
@@ -174,14 +177,19 @@ $black_mark = "2";
 $blackholemac = "00:60:8c:83:d7:34";
 use constant LOOPBACK_IPV4 => '127.0.0.1';
 
-# Captive Portal constants
-Readonly %CAPTIVE_PORTAL => (
-    "NET_DETECT_INITIAL_DELAY" => 2 * 60,
-    "NET_DETECT_RETRY_DELAY" => 30,
-);
+# Log Reload Timer in seconds
+Readonly our $LOG4PERL_RELOAD_TIMER => 5 * 60;
 
 readPfConfigFiles();
 
+# Captive Portal constants
+Readonly %CAPTIVE_PORTAL => (
+    "NET_DETECT_INITIAL_DELAY" => floor($Config{'trapping'}{'redirtimer'} / 4),
+    "NET_DETECT_RETRY_DELAY" => 2,
+    "NET_DETECT_PENDING_INITIAL_DELAY" => 2 * 60,
+    "NET_DETECT_PENDING_RETRY_DELAY" => 30,
+);
+
 readNetworkConfigFile();
 
 readFloatingNetworkDeviceFile();
