@@ -205,8 +205,8 @@ sub parseCommandLine {
                                        | ( $RE{net}{MAC} ) 
                                        | ( category | pid )
                                          \s* [=] \s*
-                                         (?: (?: \" ( [0-9a-zA-Z_\-\.\:\ ]+ ) \" ) 
-                                             | ( [0-9a-zA-Z_\-\.\:]+ )
+                                         (?: (?: \" ( [0-9a-zA-Z_\-\.\:\ \@]+ ) \" ) 
+                                             | ( [0-9a-zA-Z_\-\.\:\@]+ )
                                          )
                                      )
                                      (?:
@@ -244,6 +244,10 @@ sub parseCommandLine {
                                      (delete) \s+ (\s+)
                                    )
                                  $  }xms,
+        'nodeuseragent'   => qr{ ^ (view) 
+                                   \s+ 
+                                   ( all | \d+ (?: ,\d+)* ) 
+                                 $ }xms,
         'person'          => qr{ ^ (view)
                                    \s+
                                    ( [a-zA-Z0-9\-\_\.\@]+ )
@@ -251,13 +255,16 @@ sub parseCommandLine {
         'reload'          => qr{ ^ ( fingerprints | violations ) $  }xms,
         'report'          => qr{ ^ (?: #for grouping only
                                      ( active | inactive | openviolations 
-                                       | os | osclass | registered | statics 
-                                       | unknownprints | unregistered )
+                                       | os | osclass | registered | statics | ssid
+                                       | unknownprints | unknownuseragents | unregistered
+                                       | connectiontype | connectiontypereg
+                                     )
                                      |
                                      (?: #for grouping only
                                        ( openviolations | os | osclass 
-                                         | registered | statics
-                                         | unknownprints | unregistered 
+                                         | registered | statics | ssid
+                                         | unknownprints | unknownuseragents | unregistered 
+                                         | connectiontype | connectiontypereg
                                        )
                                        \s+
                                        ( all | active )
@@ -341,6 +348,10 @@ sub parseCommandLine {
                                    )
                                  $  }xms,
         'update'          => qr{ ^ ( fingerprints | oui ) $  }xms,
+        'useragent'       => qr{ ^ (view) 
+                                   \s+ 
+                                   ( all | \d+ ) 
+                                 $ }xms,
         'version'         => qr{ ^ $ }xms,
         'violation'       => qr{ ^ ( view )
                                    \s+
@@ -460,7 +471,7 @@ Regis Balzard <rbalzard@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009, 2010 Inverse inc.
+Copyright (C) 2009-2011 Inverse inc.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
