@@ -18,6 +18,8 @@ use Readonly;
 
 use pf::config;
 use pf::util;
+use pf::services;
+use pf::trigger;
 
 BEGIN {
     use Exporter ();
@@ -91,11 +93,13 @@ sub sanity_check {
     }
 
     database();
+    apache();
     web_admin();
     registration();
     is_config_documented();
     extensions();
     permissions();
+    violations();
 
     return @problems;
 }
@@ -327,11 +331,25 @@ database check
 =cut
 sub database {
 
-    # make sure pid 1 exists
-    require pf::person;
-    if ( !pf::person::person_exist(1) ) {
-        add_problem( $FATAL, "person user id 1 must exist - please reinitialize your database" );
-    }
+    try {
+
+        # make sure pid 1 exists
+        require pf::person;
+        if ( !pf::person::person_exist(1) ) {
+            add_problem( $FATAL, "person user id 1 must exist - please reinitialize your database" );
+        }
+
+    } catch {
+        if ($_ =~ /unable to connect to database/) {
+            add_problem( 
+                $FATAL, 
+                "Unable to connect to your database. " 
+                . "Please verify your connection settings in conf/pf.conf and make sure that it is started."
+            );
+        } else {
+            add_problem( $FATAL, "Unexpected database problem: $_" );
+        }
+    };
 
 }
 
@@ -549,12 +567,65 @@ sub permissions {
 
 }
 
+=item apache
+
+Apache related tests
+
+=cut
+sub apache {
+
+    # we dynamically adjust apache's configuration based on total system memory
+    # we will first here test if we can figure it out
+    my $total_ram = get_total_system_memory();
+    if (!defined($total_ram)) {
+        add_problem( 
+            $WARN, 
+            "Unable to find out how much system memory is available. "
+            . "We'll assume you have 2 Gigabyte. "
+            . "Please report an issue."
+        );
+    }
+
+}
+
+=item violations
+
+Checking for violations configurations
+
+=cut
+sub violations {
+    my %violations_conf;
+    tie %violations_conf, 'Config::IniFiles', ( -file => "$conf_dir/violations.conf" );
+    my @errors = @Config::IniFiles::errors;
+    if ( scalar(@errors) ) {
+        add_problem( $FATAL, "Error reading violations.conf");
+    }
+
+    my %violations = pf::services::class_set_defaults(%violations_conf);    
+
+    foreach my $violation ( keys %violations ) {
+
+        # parse triggers if they exist
+        if ( defined $violations{$violation}{'trigger'} ) {
+            try { 
+                # TODO we are parsing triggers both on checkup and when we parse the configuration on startup
+                # we probably can do something smarter here (but can't find right maintenance / efficiency balance now)
+                parse_triggers($violations{$violation}{'trigger'});
+            } catch {
+                add_problem($WARN, "Violation $violation is ignored: $_");
+            };
+        }
+    }
+}
+
 =back
 
 =head1 AUTHOR
 
 Olivier Bilodeau <obilodeau@inverse.ca>
 
+Francois Gaudreault <fgaudreault@inverse.ca>
+
 =head1 COPYRIGHT
 
 Copyright (C) 2011 Inverse inc.
