@@ -42,10 +42,18 @@ BEGIN {
         report_registered_active
         report_openviolations_all
         report_openviolations_active
+        report_connectiontype_all
+        report_connectiontype_active
+        report_connectiontypereg_all
+        report_connectiontypereg_active
+        report_ssid_all
+        report_ssid_active
         report_statics_all
         report_statics_active
         report_unknownprints_all
         report_unknownprints_active
+        report_unknownuseragents_all
+        report_unknownuseragents_active
 
         translate_connection_type
     );
@@ -119,6 +127,105 @@ sub report_db_prepare {
     $report_statements->{'report_openviolations_active_sql'} = get_db_handle()->prepare(
         qq [SELECT n.pid as owner, n.mac as mac, v.status as status, v.start_date as start_date, c.description as violation from (violation v, iplog i) LEFT JOIN node n ON v.mac=n.mac LEFT JOIN class c on c.vid=v.vid WHERE v.status="open" and n.mac=i.mac and (i.end_time=0 or i.end_time > now()) order by n.pid ]);
 
+    $report_statements->{'report_unknownuseragents_all_sql'} = get_db_handle()->prepare(qq[
+        SELECT n.user_agent, nu.browser, nu.os, n.computername, o.description, n.dhcp_fingerprint
+        FROM node as n
+            JOIN node_useragent AS nu USING (mac) 
+            LEFT JOIN dhcp_fingerprint d ON n.dhcp_fingerprint=d.fingerprint 
+            LEFT JOIN os_type o ON o.os_id=d.os_id
+        WHERE (nu.browser IS NULL OR nu.os IS NULL) AND n.user_agent != ''
+    ]);
+
+    $report_statements->{'report_unknownuseragents_active_sql'} = get_db_handle()->prepare(qq[
+        SELECT n.user_agent, nu.browser, nu.os, n.computername, o.description, n.dhcp_fingerprint
+        FROM node as n
+            JOIN node_useragent AS nu USING (mac) 
+            LEFT JOIN dhcp_fingerprint d ON n.dhcp_fingerprint=d.fingerprint 
+            LEFT JOIN os_type o ON o.os_id=d.os_id
+            LEFT JOIN iplog USING (mac)
+        WHERE (nu.browser IS NULL OR nu.os IS NULL) AND n.user_agent != '' 
+            AND (iplog.end_time=0 OR iplog.end_time > now())
+    ]);
+
+    $report_statements->{'report_connectiontype_all_sql'} = get_db_handle()->prepare(qq [
+        SELECT connection_type, count(*) as connections, ROUND(COUNT(*)/
+            (SELECT COUNT(*) FROM locationlog 
+                INNER JOIN node ON node.mac=locationlog.mac WHERE locationlog.end_time IS NULL)*100,1
+            ) AS percent 
+        FROM locationlog INNER JOIN node ON node.mac=locationlog.mac 
+        WHERE locationlog.end_time IS NULL
+        GROUP BY connection_type
+    ]);
+
+    $report_statements->{'report_connectiontype_active_sql'} = get_db_handle()->prepare(qq[
+        SELECT connection_type,count(*) as connections, 
+            ROUND( COUNT(*) / 
+                (SELECT COUNT(*) FROM locationlog INNER JOIN node ON node.mac=locationlog.mac 
+                    INNER JOIN iplog ON node.mac=iplog.mac 
+                    WHERE iplog.end_time = 0 OR iplog.end_time > now() AND locationlog.end_time IS NULL
+                )*100,1
+            ) AS percent 
+        FROM locationlog INNER JOIN node ON node.mac=locationlog.mac INNER JOIN iplog ON node.mac=iplog.mac 
+        WHERE iplog.end_time = 0 OR iplog.end_time > now() AND locationlog.end_time IS NULL 
+        GROUP BY connection_type
+    ]);
+   
+    $report_statements->{'report_connectiontypereg_all_sql'} = get_db_handle()->prepare(qq[
+        SELECT connection_type, count(*) as connections, 
+            ROUND( COUNT(*) / 
+                (SELECT COUNT(*) FROM locationlog INNER JOIN node ON node.mac=locationlog.mac 
+                    WHERE node.status = "reg" AND locationlog.end_time IS NULL
+                )*100,1
+            ) AS percent 
+        FROM locationlog INNER JOIN node ON node.mac=locationlog.mac 
+        WHERE node.status = "reg" AND locationlog.end_time IS NULL 
+        GROUP BY connection_type
+    ]);
+
+    $report_statements->{'report_connectiontypereg_active_sql'} = get_db_handle()->prepare(qq[
+        SELECT connection_type, count(*) as connections, 
+            ROUND( COUNT(*) / 
+                (SELECT COUNT(*) FROM locationlog 
+                    INNER JOIN node ON node.mac=locationlog.mac INNER JOIN iplog ON node.mac=iplog.mac 
+                    WHERE node.status = "reg" AND (iplog.end_time =0 OR iplog.end_time > now()) 
+                        AND locationlog.end_time IS NULL
+                )*100,1
+            ) AS percent 
+        FROM locationlog INNER JOIN node ON node.mac=locationlog.mac INNER JOIN iplog ON node.mac=iplog.mac 
+        WHERE node.status = "reg" AND (iplog.end_time = 0 OR iplog.end_time > now()) AND locationlog.end_time IS NULL 
+        GROUP BY connection_type
+    ]);
+
+    $report_statements->{'report_ssid_all_sql'} = get_db_handle()->prepare(qq [
+        SELECT ssid,count(*) as nodes, ROUND(COUNT(*)/
+            (SELECT COUNT(*) 
+                FROM locationlog
+                    INNER JOIN node ON node.mac=locationlog.mac AND locationlog.end_time IS NULL
+                WHERE ssid != "")
+            *100,1) as percent 
+        FROM locationlog 
+           INNER JOIN node ON node.mac=locationlog.mac AND locationlog.end_time IS NULL
+        WHERE ssid != ""
+        GROUP BY ssid 
+        ORDER BY nodes
+    ]);
+
+    $report_statements->{'report_ssid_active_sql'} = get_db_handle()->prepare(qq [
+       SELECT ssid,count(*) as nodes, ROUND(COUNT(*)/
+           (SELECT COUNT(*) 
+                FROM locationlog 
+                    INNER JOIN node ON node.mac=locationlog.mac AND locationlog.end_time IS NULL
+                    INNER JOIN iplog ON node.mac=iplog.mac 
+                WHERE ssid != "" AND (iplog.end_time=0 OR iplog.end_time > now())
+           )*100,1) as percent 
+       FROM locationlog 
+           INNER JOIN node ON node.mac=locationlog.mac AND locationlog.end_time IS NULL
+           INNER JOIN iplog ON node.mac=iplog.mac 
+       WHERE ssid != "" AND (iplog.end_time=0 OR iplog.end_time > now()) 
+       GROUP BY ssid 
+       ORDER BY nodes
+    ]);
+
     $report_db_prepared = 1;
     return 1;
 }
@@ -327,6 +434,152 @@ sub report_unknownprints_active {
     return (@data);
 }
 
+sub report_unknownuseragents_all {
+    return db_data(REPORT, $report_statements, 'report_unknownuseragents_all_sql');
+}
+
+sub report_unknownuseragents_active {
+    return db_data(REPORT, $report_statements, 'report_unknownuseragents_active_sql');
+}
+
+=item * report_connectiontype_all
+
+Reporting - Connections by connection type and user status for all nodes
+
+=cut
+sub report_connectiontype_all {
+    my @data    = db_data(REPORT, $report_statements, 'report_connectiontype_all_sql');
+    my $total   = 0;
+    my @return_data;
+
+    foreach my $record (@data) {
+        $total += $record->{'connections'};
+ 
+        if ( $record->{'connections'} > 0 ) {
+            push @return_data, $record;
+        }
+
+    }
+    @return_data = translate_connection_type(@return_data);
+    push @return_data, { connection_type => "Total", percent => "100", connections => $total };
+    return (@return_data);
+}
+
+=item * report_connectiontype_active
+
+Reporting - Connections by connection type and user status for all active nodes
+
+=cut
+sub report_connectiontype_active {
+    my @data    = db_data(REPORT, $report_statements, 'report_connectiontype_active_sql');
+    my $total   = 0;
+    my @return_data;
+
+    foreach my $record (@data) {
+        $total += $record->{'connections'};
+
+        if ( $record->{'connections'} > 0 ) {
+            push @return_data, $record;
+        }
+
+    }
+    @return_data = translate_connection_type(@return_data);
+    push @return_data, { connection_type => "Total", percent => "100", connections => $total };
+    return (@return_data);
+}
+
+=item * report_connectiontypereg_all
+
+Reporting - Connections by connection type and user status for all nodes (registered users)
+
+=cut
+sub report_connectiontypereg_all {
+    my @data    = db_data(REPORT, $report_statements, 'report_connectiontypereg_all_sql');
+    my $total   = 0;
+    my @return_data;
+
+    foreach my $record (@data) {
+        $total += $record->{'connections'};
+
+        if ( $record->{'connections'} > 0 ) {
+            push @return_data, $record;
+        }
+
+    }
+    @return_data = translate_connection_type(@return_data);
+    push @return_data, { connection_type => "Total", percent => "100", connections => $total };
+    return (@return_data);
+}
+
+=item * report_connectiontypereg_active
+
+Reporting - Connections by connection type and user status for all active nodes (registered users)
+
+=cut
+sub report_connectiontypereg_active {
+    my @data    = db_data(REPORT, $report_statements, 'report_connectiontypereg_active_sql');
+    my $total   = 0;
+    my @return_data;
+
+    foreach my $record (@data) {
+        $total += $record->{'connections'};
+
+        if ( $record->{'connections'} > 0 ) {
+            push @return_data, $record;
+        }
+
+    }
+    @return_data = translate_connection_type(@return_data);
+    push @return_data, { connection_type => "Total", percent => "100", connections => $total };
+    return (@return_data);
+}
+
+=item * report_ssid_all
+
+Reporting - Connections by SSID for all nodes regardless of the status
+
+=cut
+sub report_ssid_all {
+    my @data    = db_data(REPORT, $report_statements, 'report_ssid_all_sql');
+    my $total   = 0;
+    my @return_data;
+
+    foreach my $record (@data) {
+        $total += $record->{'nodes'};
+
+        if ( $record->{'nodes'} > 0 ) {
+            push @return_data, $record;
+        }
+
+    }
+
+    push @return_data, { ssid => "Total", percent => "100", nodes => $total };
+    return (@return_data);
+}
+
+=item * report_ssid_active
+
+Reporting - Connections by SSID for all active nodes (reg/unreg)
+
+=cut
+sub report_ssid_active {
+    my @data    = db_data(REPORT, $report_statements, 'report_ssid_active_sql');
+    my $total   = 0;
+    my @return_data;
+
+    foreach my $record (@data) {
+        $total += $record->{'nodes'};
+
+        if ( $record->{'nodes'} > 0 ) {
+            push @return_data, $record;
+        }
+
+    }
+
+    push @return_data, { ssid => "Total", percent => "100", nodes => $total };
+    return (@return_data);
+}
+
 =item * translate_connection_type
 
 Translates connection_type database string into a human-understandable string
@@ -369,13 +622,17 @@ Kevin Amorin <kev@amorin.org>
 
 Olivier Bilodeau <obilodeau@inverse.ca>
 
+Francois Gaudreault <fgaudreault@inverse.ca>
+
 =head1 COPYRIGHT
 
 Copyright (C) 2005 David LaPorte
 
 Copyright (C) 2005 Kevin Amorin
 
-Copyright (C) 2010 Inverse inc.
+Copyright (C) 2010-2011 Inverse inc.
+
+=head1 LICENSE
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -395,3 +652,6 @@ USA.
 =cut
 
 1;
+# vim: set shiftwidth=4:
+# vim: set expandtab:
+# vim: set backspace=indent,eol,start:
