@@ -23,18 +23,19 @@ F<snort.conf>, F<httpd.conf>, F<snmptrapd.conf>.
 
 use strict;
 use warnings;
-use File::Basename;
 use Config::IniFiles;
+use File::Basename;
+use IPC::Cmd qw[can_run run];
 use Log::Log4perl;
 use Readonly;
+use Try::Tiny;
 use UNIVERSAL::require;
-use IPC::Cmd qw[can_run run];
 
 use pf::config;
 use pf::util;
 use pf::violation qw(violation_view_open_uniq);
 use pf::node qw(nodes_registered_not_violators);
-use pf::trigger qw(trigger_delete_all);
+use pf::trigger qw(trigger_delete_all parse_triggers);
 use pf::class qw(class_view_all class_merge);
 use pf::services::apache;
 use pf::SwitchFactory;
@@ -287,7 +288,7 @@ sub generate_named_conf {
     require Net::Netmask;
     import Net::Netmask;
     my %tags;
-    $tags{'template'}    = "$conf_dir/templates/named_vlan.conf";
+    $tags{'template'}    = "$conf_dir/named_vlan.conf";
     $tags{'install_dir'} = $install_dir;
 
     my %network_conf;
@@ -330,36 +331,28 @@ sub generate_named_conf {
     }
     parse_template(
         \%tags,
-        "$conf_dir/templates/named_vlan.conf",
+        "$conf_dir/named_vlan.conf",
         "$generated_conf_dir/named.conf"
     );
 
     my %tags_isolation;
-    $tags_isolation{'template'} = "$conf_dir/templates/named-isolation.ca";
+    $tags_isolation{'template'} = "$conf_dir/named-isolation.ca";
     $tags_isolation{'hostname'} = $Config{'general'}{'hostname'};
     $tags_isolation{'incharge'}
         = "pf."
         . $Config{'general'}{'hostname'} . "."
         . $Config{'general'}{'domain'};
-    parse_template(
-        \%tags_isolation,
-        "$conf_dir/templates/named-isolation.ca",
-        "$var_dir/named/named-isolation.ca"
-    );
+    parse_template(\%tags_isolation, "$conf_dir/named-isolation.ca", "$var_dir/named/named-isolation.ca", ";");
 
     my %tags_registration;
     $tags_registration{'template'}
-        = "$conf_dir/templates/named-registration.ca";
+        = "$conf_dir/named-registration.ca";
     $tags_registration{'hostname'} = $Config{'general'}{'hostname'};
     $tags_registration{'incharge'}
         = "pf."
         . $Config{'general'}{'hostname'} . "."
         . $Config{'general'}{'domain'};
-    parse_template(
-        \%tags_registration,
-        "$conf_dir/templates/named-registration.ca",
-        "$var_dir/named/named-registration.ca"
-    );
+    parse_template(\%tags_registration, "$conf_dir/named-registration.ca", "$var_dir/named/named-registration.ca", ";");
 
     return 1;
 }
@@ -369,7 +362,7 @@ sub manage_Static_Route {
     my $add_Route = @_;
     my $logger = Log::Log4perl::get_logger('pf::services');
     my %tags;
-    $tags{'template'}    = "$conf_dir/templates/named_vlan.conf";
+    $tags{'template'}    = "$conf_dir/named_vlan.conf";
     $tags{'install_dir'} = $install_dir;
 
     my %network_conf;
@@ -408,7 +401,7 @@ sub manage_Static_Route {
 sub generate_dhcpd_vlan_conf {
     my $logger = Log::Log4perl::get_logger('pf::services');
     my %tags;
-    $tags{'template'} = "$conf_dir/templates/dhcpd_vlan.conf";
+    $tags{'template'} = "$conf_dir/dhcpd_vlan.conf";
     $tags{'networks'} = '';
 
     my %network_conf;
@@ -440,7 +433,7 @@ EOT
         }
     }
 
-    parse_template( \%tags, "$conf_dir/templates/dhcpd_vlan.conf",
+    parse_template( \%tags, "$conf_dir/dhcpd_vlan.conf",
         "$generated_conf_dir/dhcpd.conf" );
 
     return 1;
@@ -457,12 +450,12 @@ sub generate_dhcpd_conf {
     }
     my %tags;
     my $logger = Log::Log4perl::get_logger('pf::services');
-    $tags{'template'}   = "$conf_dir/templates/dhcpd.conf";
+    $tags{'template'}   = "$conf_dir/dhcpd.conf";
     $tags{'domain'}     = $Config{'general'}{'domain'};
     $tags{'hostname'}   = $Config{'general'}{'hostname'};
     $tags{'dnsservers'} = $Config{'general'}{'dnsservers'};
 
-    parse_template( \%tags, "$conf_dir/templates/dhcpd.conf",
+    parse_template( \%tags, "$conf_dir/dhcpd.conf",
         "$generated_conf_dir/dhcpd.conf" );
 
     my %shared_nets;
@@ -771,7 +764,7 @@ sub generate_dhcpd_reg {
 sub generate_snort_conf {
     my $logger = Log::Log4perl::get_logger('pf::services');
     my %tags;
-    $tags{'template'}      = "$conf_dir/templates/snort.conf";
+    $tags{'template'}      = "$conf_dir/snort.conf";
     $tags{'internal-ips'}  = join( ",", get_internal_ips() );
     $tags{'internal-nets'} = join( ",", get_internal_nets() );
     $tags{'gateways'}      = join( ",", get_gateways() );
@@ -800,7 +793,7 @@ sub generate_snort_conf {
     }
     $tags{'snort_rules'} = join( "\n", @rules );
     $logger->info("generating $conf_dir/snort.conf");
-    parse_template( \%tags, "$conf_dir/templates/snort.conf",
+    parse_template( \%tags, "$conf_dir/snort.conf",
         "$generated_conf_dir/snort.conf" );
     return 1;
 }
@@ -853,82 +846,13 @@ sub generate_snmptrapd_conf {
     foreach my $community ( sort keys %SNMPCommunities ) {
         $tags{'authLines'} .= "authCommunity log $community\n";
     }
-    $tags{'template'} = "$conf_dir/templates/snmptrapd.conf";
+    $tags{'template'} = "$conf_dir/snmptrapd.conf";
     $logger->info("generating $generated_conf_dir/snmptrapd.conf");
-    parse_template( \%tags, "$conf_dir/templates/snmptrapd.conf",
+    parse_template( \%tags, "$conf_dir/snmptrapd.conf",
         "$generated_conf_dir/snmptrapd.conf" );
     return 1;
 }
 
-=item * generate_httpd_conf
-
-=cut
-
-sub generate_httpd_conf {
-    my ( %tags, $httpdconf_fh, $authconf_fh );
-    my $logger = Log::Log4perl::get_logger('pf::services');
-    $tags{'template'}      = "$conf_dir/templates/httpd.conf";
-    $tags{'internal-nets'} = join( " ", get_internal_nets() );
-    $tags{'routed-nets'}   = join( " ", get_routed_isolation_nets() ) . " "
-        . join( " ", get_routed_registration_nets() );
-    $tags{'hostname'}    = $Config{'general'}{'hostname'};
-    $tags{'domain'}      = $Config{'general'}{'domain'};
-    $tags{'admin_port'}  = $Config{'ports'}{'admin'};
-    $tags{'install_dir'} = $install_dir;
-
-    my @proxies;
-    my %proxy_configs = %{ $Config{'proxies'} };
-    foreach my $proxy ( keys %proxy_configs ) {
-        if ( $proxy =~ /^\// ) {
-            if ( $proxy !~ /^\/(content|admin|redirect|cgi-bin)/ ) {
-                push @proxies,
-                    "ProxyPassReverse $proxy $proxy_configs{$proxy}";
-                push @proxies, "ProxyPass $proxy $proxy_configs{$proxy}";
-                $logger->warn(
-                    "proxy $proxy is not relative - add path to apache rewrite exclude list!"
-                );
-            } else {
-                $logger->warn("proxy $proxy conflicts with PF paths!");
-                next;
-            }
-        } else {
-            push @proxies,
-                  "ProxyPassReverse /proxies/" 
-                . $proxy . " "
-                . $proxy_configs{$proxy};
-            push @proxies,
-                "ProxyPass /proxies/" . $proxy . " " . $proxy_configs{$proxy};
-        }
-    }
-    $tags{'proxies'} = join( "\n", @proxies );
-
-    my ($pt_http, $pt_https, $remediation);
-    if ( $Config{'trapping'}{'passthrough'} eq "proxy" ) {
-
-        ($pt_http, $pt_https) = generate_passthrough_rewrite_proxy_config(%{ $Config{'passthroughs'} });
-
-        # remediation passthrough (for violation.conf url=http:// or https://)
-        $remediation = generate_remediation_rewrite_proxy_config(class_view_all());
-    }
-
-    # if config doesn't exist, replace it with empty array
-    foreach my $template ($remediation, $pt_http, $pt_https) {
-        if (!defined($template)) {
-            $template = [ ];
-        }
-    }
-
-    # associate config to templates
-    $tags{'remediation-proxies'} = join( "\n", @{$remediation});
-    $tags{'passthrough-http-proxies'} = join("\n", @{$pt_http});
-    $tags{'passthrough-https-proxies'} = join("\n", @{$pt_https});
-
-    $logger->info("generating $generated_conf_dir/httpd.conf");
-    parse_template( \%tags, "$conf_dir/templates/httpd.conf",
-        "$generated_conf_dir/httpd.conf" );
-    return 1;
-}
-
 =item * switches_conf_is_valid
 
 =cut
@@ -1021,10 +945,7 @@ sub switches_conf_is_valid {
             }
 
             # check mode
-            my @valid_switch_modes = (
-                'testing', 'ignore', 'production', 'registration',
-                'discovery'
-            );
+            my @valid_switch_modes = ( 'testing', 'ignore', 'production', 'registration', 'discovery' );
             my $mode = $switches_conf{$section}{'mode'}
                 || $switches_conf{'default'}{'mode'};
             if ( !grep( { lc($_) eq lc($mode) } @valid_switch_modes ) ) {
@@ -1047,12 +968,10 @@ sub switches_conf_is_valid {
 sub read_violations_conf {
     my $logger = Log::Log4perl::get_logger('pf::services');
     my %violations_conf;
-    tie %violations_conf, 'Config::IniFiles',
-        ( -file => "$conf_dir/violations.conf" );
+    tie %violations_conf, 'Config::IniFiles', ( -file => "$conf_dir/violations.conf" );
     my @errors = @Config::IniFiles::errors;
     if ( scalar(@errors) ) {
-        $logger->error( "Error reading violations.conf: " 
-                        .  join( "\n", @errors ) . "\n" );
+        $logger->error( "Error reading violations.conf: " .  join( "\n", @errors ) . "\n" );
         return 0;
     }
     my %violations = class_set_defaults(%violations_conf);
@@ -1062,27 +981,23 @@ sub read_violations_conf {
     foreach my $violation ( keys %violations ) {
 
         # parse triggers if they exist
-        my @triggers;
+        my $triggers_ref = [];
         if ( defined $violations{$violation}{'trigger'} ) {
-            foreach my $trigger (
-                split( /\s*,\s*/, $violations{$violation}{'trigger'} ) )
-            {
-                my ( $type, $tid ) = split( /::/, $trigger );
-                $type = lc($type);
-                if ( !grep( { lc($_) eq lc($type) } @valid_trigger_types ) ) {
-                    $logger->warn(
-                        "invalid trigger '$type' found at $violation");
-                    next;
-                }
-                if ( $tid =~ /(\d+)-(\d+)/ ) {
-                    push @triggers, [ $1, $2, $type ];
-                } else {
-                    push @triggers, [ $tid, $tid, $type ];
-                }
-            }
+            try {
+                $triggers_ref = parse_triggers($violations{$violation}{'trigger'});
+            } catch {
+                $logger->warn("Violation $violation is ignored: $_");
+                $triggers_ref = [];
+            };
+        }
+
+        # parse grace, try to understand trailing signs, and convert back to seconds 
+        if ( defined $violations{$violation}{'grace'} ) {
+            # If we can detect s, m, h, d, w or y at the end of the string, we recalculate the number of seconds
+            # if we have nothing, we consider it is seconds (s=seconds, m=minutes, h=hours, d=days, w=weeks, y=years)
+            $violations{$violation}{'grace'} = normalize_time($violations{$violation}{'grace'});
         }
 
-        #print Dumper(@triggers);
         # be careful of the way parameters are passed, whitelists, actions and triggers are expected at the end
         class_merge(
             $violation,
@@ -1099,7 +1014,7 @@ sub read_violations_conf {
             $violations{$violation}{'vlan'},
             $violations{$violation}{'whitelisted_categories'},
             $violations{$violation}{'actions'},
-            \@triggers
+            $triggers_ref
         );
     }
     return 1;
@@ -1167,7 +1082,7 @@ Copyright (C) 2005 David LaPorte
 
 Copyright (C) 2005 Kevin Amorin
 
-Copyright (C) 2009,2010 Inverse inc.
+Copyright (C) 2009-2011 Inverse inc.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
