@@ -32,14 +32,17 @@ BEGIN {
     use Exporter ();
     our ( @ISA, @EXPORT );
     @ISA = qw(Exporter);
-    @EXPORT
-        = qw(valid_date valid_ip clean_mac valid_mac get_decimal_oui_from_mac whitelisted_mac trappable_mac trappable_ip reggable_ip
+    @EXPORT = qw(
+        valid_date valid_ip clean_mac valid_mac get_decimal_oui_from_mac whitelisted_mac trappable_mac 
+        trappable_ip reggable_ip
         inrange_ip ip2gateway ip2interface ip2device isinternal pfmailer isenabled
-        isdisabled getlocalmac ip2int int2ip get_all_internal_ips get_internal_nets get_routed_isolation_nets get_routed_registration_nets get_internal_ips
+        isdisabled getlocalmac ip2int int2ip 
+        get_all_internal_ips get_internal_nets get_routed_isolation_nets get_routed_registration_nets get_internal_ips
         get_internal_devs get_internal_devs_phy get_external_devs get_managed_devs get_internal_macs
         get_internal_info get_gateways get_dhcp_devs createpid readpid deletepid
-        pfmon_preload parse_template mysql_date oui_to_vendor mac2oid oid2mac str_to_connection_type 
-        connection_type_to_str
+        pfmon_preload parse_template mysql_date oui_to_vendor mac2oid oid2mac 
+        str_to_connection_type connection_type_to_str
+        get_total_system_memory
     );
 }
 
@@ -97,7 +100,7 @@ sub valid_ip {
 
 =item clean_mac 
 
-Clean a MAC address accepting xx-xx-xx-xx-xx-xx, xx:xx:xx:xx:xx:xx and xxxx.xxxx.xxxx.
+Clean a MAC address accepting xx-xx-xx-xx-xx-xx, xx:xx:xx:xx:xx:xx, xxxx-xxxx-xxxx and xxxx.xxxx.xxxx.
 
 Returns a string with MAC in format: xx:xx:xx:xx:xx:xx
 
@@ -105,19 +108,21 @@ Returns a string with MAC in format: xx:xx:xx:xx:xx:xx
 sub clean_mac {
     my ($mac) = @_;
     return (0) if ( !$mac );
-    $mac =~ s/\s//g;
+    # trim garbage
+    $mac =~ s/[\s\-\.:]//g;
+    # lowercase
     $mac = lc($mac);
-    $mac =~ s/\.//g if ( $mac =~ /^([0-9a-f]{4}(\.|$)){3}$/i );
+    # inject :
     $mac =~ s/([a-f0-9]{2})(?!$)/$1:/g if ( $mac =~ /^[a-f0-9]{12}$/i );
-    $mac = join q {:} => map { sprintf "%02x" => hex } split m {:|\-} => $mac;
     return ($mac);
 }
 
+
 =item valid_mac 
 
 Validates MAC addresses. Returns 1 or 0 (true or false)
 
-Accepting xx-xx-xx-xx-xx-xx, xx:xx:xx:xx:xx:xx and xxxx.xxxx.xxxx
+Accepting xx-xx-xx-xx-xx-xx, xx:xx:xx:xx:xx:xx, xxxx-xxxx-xxxx and xxxx.xxxx.xxxx
 
 =cut
 sub valid_mac {
@@ -591,12 +596,11 @@ sub deletepid {
 }
 
 sub parse_template {
-    my ( $tags, $template, $destination ) = @_;
+    my ( $tags, $template, $destination, $comment_char ) = @_;
     my $logger = Log::Log4perl::get_logger('pf::util');
     my (@parsed);
     my $template_fh;
-    open( $template_fh, '<', $template )
-        || $logger->logcroak("Unable to open template $template: $!");
+    open( $template_fh, '<', $template ) || $logger->logcroak("Unable to open template $template: $!");
     while (<$template_fh>) {
         study $_;
         foreach my $tag ( keys %{$tags} ) {
@@ -605,12 +609,18 @@ sub parse_template {
         push @parsed, $_;
     }
 
+    # add generated file header (inserting in front of array)
+    $comment_char = "#" if (!defined($comment_char));
+    unshift @parsed, 
+        "$comment_char This file is generated from a template at $template\n"
+        ."$comment_char Any changes made to this file will be lost on restart\n\n";
+
     #close(TEMPLATE);
     if ($destination) {
         my $destination_fh;
         open( $destination_fh, ">", $destination )
-            || $logger->logcroak(
-            "Unable to open template destination $destination: $!");
+            || $logger->logcroak( "Unable to open template destination $destination: $!");
+
         foreach my $line (@parsed) {
             print {$destination_fh} $line;
         }
@@ -744,7 +754,7 @@ sub preload_is_internal {
     return (%is_internal);
 }
 
-=item * connection_type_to_str
+=item connection_type_to_str
 
 In the database we store the connection type as a string but we use a constant binary value internally. 
 This converts from the constant binary value to the string.
@@ -767,7 +777,7 @@ sub connection_type_to_str {
     }
 }
 
-=item * str_to_connection_type
+=item str_to_connection_type
 
 In the database we store the connection type as a string but we use a constant binary value internally. 
 This parses the string from the database into the the constant binary value.
@@ -795,6 +805,33 @@ sub str_to_connection_type {
     }
 }
 
+=item get_total_system_memory
+
+Returns the total amount of memory in kilobytes. Undef if something went wrong or it can't determined.
+
+=cut
+sub get_total_system_memory {
+    my $logger = Log::Log4perl::get_logger('pf::util');
+
+
+    my $result = open(my $meminfo_fh , '<', '/proc/meminfo');
+    if (!defined($result)) {
+        $logger->warn("Unable to open /proc/meminfo: $!");
+        return;
+    }
+
+    my $total_mem; # in kilobytes
+    while (<$meminfo_fh>) {
+
+        if (m/^MemTotal:\s+(\d+) kB/) {
+            $total_mem = $1;
+            last;
+        }
+    }
+
+    return $total_mem;
+}
+
 =back
 
 =head1 AUTHOR
