@@ -25,6 +25,7 @@ F<register.html>.
 #TODO all template destination should be variables allowing redefinitions by pf::web::custom
 use strict;
 use warnings;
+
 use Date::Parse;
 use File::Basename;
 use JSON;
@@ -87,35 +88,37 @@ sub generate_release_page {
         logo            => $Config{'general'}{'logo'},
         timer           => $Config{'trapping'}{'redirtimer'},
         destination_url => $destination_url,
+        redirect_url => $Config{'trapping'}{'redirecturl'},
         txt_page_title  => gettext("release: enabling network"),
-        txt_message     => sprintf(
-            gettext("network access is being enabled"),
-            $Config{'trapping'}{'redirtimer'}
+        txt_message     => gettext("network access is being enabled"),
+        txt_opera => gettext(
+            "There are known issues with the automatic redirection on Opera browsers. " 
+            . "Please open a new browser window from time to time to see if your access was enabled."
         ),
-        txt_enabling => gettext("Enabling ..."),
+        txt_ie => gettext("Some versions of Internet Explorer may take a while before redirection occur."),
+        txt_noscript => gettext(
+            "If you have scripting turned off, you will not be automatically redirected. "
+            . "Please enable scripting or open a new browser window from time to time " 
+            . "to see if your access was enabled."
+        ),
+        txt_timerexpired => gettext(
+            "Unable to detect network connectivity. "
+            . "Try opening a web page to see if your access has been succesfully enabled."
+        ),
+        initial_delay => $CAPTIVE_PORTAL{'NET_DETECT_INITIAL_DELAY'},
+        retry_delay => $CAPTIVE_PORTAL{'NET_DETECT_RETRY_DELAY'},
+        external_ip => $Config{'captive_portal'}{'network_detection_ip'},
     };
-    if ( $Config{'network'}{'mode'} =~ /vlan/i ) {
-        $vars->{js_action} = "var action = function()
-{
-  hidebar();
-  var toReplace=document.getElementById('toReplace');
-  toReplace.innerHTML = '<font face=\"Arial\">"
-            . gettext("release: reopen browser")
-            . "</font>';
-}";
-    } else {
-        $vars->{js_action} = <<EOT;
-var action = function() 
-{
-  hidebar();
-  top.location.href=destination_url;
-}
-EOT
+
+    # override destination_url if we enabled the always_use_redirecturl option
+    if (isenabled($Config{'trapping'}{'always_use_redirecturl'})) {
+        $vars->{'destination_url'} = $Config{'trapping'}{'redirecturl'};
     }
+
     my $html_txt;
-    my $template = Template->new(
-        { INCLUDE_PATH => ["$install_dir/html/user/content/templates"], } );
+    my $template = Template->new({ INCLUDE_PATH => ["$install_dir/html/user/content/templates"], });
     $template->process( "release.html", $vars, \$html_txt );
+
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
     print $cgi->header(
         -cookie         => $cookie,
@@ -448,35 +451,31 @@ sub _sanitize_and_register {
     return 1;
 }
 
+=item web_node_record_user_agent
+
+Records User-Agent for the provided node and triggers violations.
+
+=cut
 sub web_node_record_user_agent {
     my ( $mac, $user_agent ) = @_;
     my $logger = Log::Log4perl::get_logger('pf::web');
     
+    # caching useragents, if it's the same don't bother triggering violations
+    my $cached_useragent = $main::useragent_cache->get($mac);
+
+    # Cache hit
+    return if (defined($cached_useragent) && $user_agent eq $cached_useragent);
+
+    # Caching and updating node's info
+    $logger->trace("adding $mac user-agent to cache");
+    $main::useragent_cache->set( $mac, $user_agent, "5 minutes");
+
     # Recording useragent
     $logger->info("Updating node $mac user_agent with useragent: '$user_agent'");
-    # call node_modify directly instead of pfcmd node edit. it's more performant and it'll avoid trying to adjust vlan 
     node_modify($mac, ('user_agent' => $user_agent));
 
-    # match provided useragent in useragent database
-    my @user_agent_info = useragent_match($user_agent);
-    if ( scalar(@user_agent_info) && ( ref( $user_agent_info[0] ) eq 'HASH' ) ) {
-
-        # is there a violation on this user agent?
-        $logger->debug(
-            "sending USERAGENT::".$user_agent_info[0]->{'useragent_id'}
-            ." (".$user_agent_info[0]->{'useragent'}.") trigger"
-        );
-        require pf::violation;
-        # TODO we should also trigger the broader class (ex: 101 and 1 for a useragent id 101 which is part of class 1)
-        # issue #1192
-        pf::violation::violation_trigger( $mac, $user_agent_info[0]->{'useragent_id'}, "USERAGENT" );
-
-    } else {
-        $logger->info("unknown User-Agent: " . $user_agent);
-        # TODO: record unknown useragents here? (how does dhcp fingerprint does it?)
-    }
-
-    return 1;
+    # updates the node_useragent information and fires relevant violations triggers
+    return pf::useragent::process_useragent($mac, $user_agent);
 }
 
 sub web_user_authenticate {
@@ -635,11 +634,22 @@ sub generate_pending_page {
             { name => gettext('MAC'), value => $mac }
         ],
         destination_url => $destination_url,
-        initial_delay => $CAPTIVE_PORTAL{'NET_DETECT_INITIAL_DELAY'},
-        retry_delay => $CAPTIVE_PORTAL{'NET_DETECT_RETRY_DELAY'},
+        redirect_url => $Config{'trapping'}{'redirecturl'},
+        txt_opera => gettext(
+            "There are known issues with the automatic redirection on Opera browsers. " 
+            . "Please open a new browser window from time to time to see if your access was enabled."
+        ),
+        txt_ie => gettext("Some versions of Internet Explorer may take a while before redirection occur."),
+        initial_delay => $CAPTIVE_PORTAL{'NET_DETECT_PENDING_INITIAL_DELAY'},
+        retry_delay => $CAPTIVE_PORTAL{'NET_DETECT_PENDING_RETRY_DELAY'},
         external_ip => $Config{'captive_portal'}{'network_detection_ip'},
     };
 
+    # override destination_url if we enabled the always_use_redirecturl option
+    if (isenabled($Config{'trapping'}{'always_use_redirecturl'})) {
+        $vars->{'destination_url'} = $Config{'trapping'}{'redirecturl'};
+    }
+
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
     print $cgi->header( -cookie => $cookie );
 
